// Ionic Starter App
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services', 'ionic-citydata', 'ionic-citypicker'], function ($httpProvider) {
        // Use x-www-form-urlencoded Content-Type
        $httpProvider.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=utf-8';
        /**
         * The workhorse; converts an object to x-www-form-urlencoded serialization.
         * @param {Object} obj
         * @return {String}
         */
        var param = function (obj) {
            var query = '', name, value, fullSubName, subName, subValue, innerObj, i;
            for (name in obj) {
                value = obj[name];
                if (value instanceof Array) {
                    for (i = 0; i < value.length; ++i) {
                        subValue = value[i];
                        fullSubName = name + '[' + i + ']';
                        innerObj = {};
                        innerObj[fullSubName] = subValue;
                        query += param(innerObj) + '&';
                    }
                }
                else if (value instanceof Object) {
                    for (subName in value) {
                        subValue = value[subName];
                        fullSubName = name + '[' + subName + ']';
                        innerObj = {};
                        innerObj[fullSubName] = subValue;
                        query += param(innerObj) + '&';
                    }
                }
                else if (value !== undefined && value !== null)
                    query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
            }
            return query.length ? query.substr(0, query.length - 1) : query;
        };
        // Override $http service's default transformRequest
        $httpProvider.defaults.transformRequest = [function (data) {
            return angular.isObject(data) && String(data) !== '[object File]' ? param(data) : data;
        }];


    })

    .run(function ($ionicPlatform) {
        $ionicPlatform.ready(function () {
            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                cordova.plugins.Keyboard.disableScroll(true);
            }
            if (window.StatusBar) {
                // org.apache.cordova.statusbar required
                StatusBar.styleDefault();
            }
        });

    })

    .config(function ($stateProvider, $urlRouterProvider, $ionicConfigProvider) {

        $ionicConfigProvider.platform.ios.tabs.style('standard');
        $ionicConfigProvider.platform.ios.tabs.position('bottom');
        $ionicConfigProvider.platform.android.tabs.style('standard');
        $ionicConfigProvider.platform.android.tabs.position('bottom');
        $ionicConfigProvider.platform.ios.navBar.alignTitle('center');
        $ionicConfigProvider.platform.android.navBar.alignTitle('center');
        $ionicConfigProvider.platform.ios.backButton.previousTitleText(' ').icon('ion-ios-arrow-thin-left');
        $ionicConfigProvider.platform.android.backButton.previousTitleText(' ').icon('ion-android-arrow-back');
        $ionicConfigProvider.platform.ios.views.transition('ios');
        $ionicConfigProvider.platform.android.views.transition('android');
        $ionicConfigProvider.backButton.previousTitleText(false);

        $stateProvider
        /* .state('tab', {
         url: '/tab',
         cache:false,
         abstract: true,
         templateUrl: 'templates/tabs.html'
         })*/
        // 我  个人中心
            .state("mine", {
                url: "/mine",
                cache: false,
                abstract: true,
                templateUrl: 'templates/tabs.html',
                controller: 'tabCtrl'
            })
			 .state("others", {
                url: "/others",
                abstract: true,
                template: '<ion-nav-view></ion-nav-view>',
                controller:"otherCtrl"
            })
            //发现
            .state("find", {
                url: "/find",
                cache: false,
                abstract: true,
                templateUrl: 'templates/tabs.html',
                controller: 'tabCtrl'
            })
//公会活动
            .state("union", {
                url: "/union",
                cache: false,
                abstract: true,
                templateUrl: 'templates/tabs.html',
                controller: 'tabCtrl'
            })

            //我  个人中心开始
            .state('mine.mine', {
                url: '/mine',
                cache: true,
                views: {
                    'mine': {
                        templateUrl: 'templates/mine/personCenter.html',
                        controller: 'personCenterController'
                    }
                }
            })
            //注册
            .state('mine.register', {
                url: '/register',
                cache: true,
                views: {
                    'mine': {
                        templateUrl: 'templates/mine/register.html',
                        controller: 'userRegisterController'
                    }
                }
            })
			//登录
			.state('mine.login', {
                url: '/login',
                cache: true,
                views: {
                    'mine': {
                        templateUrl: 'templates/mine/dl.html',
                        controller: 'loginController'
                    }
                }
            })
            //公会活动
            .state('union.unionCenter', {
                url: '/unionCenter',
                cache: true,
                views: {
                    'union': {
                        templateUrl: 'templates/union/unionCenter.html',
                        controller: 'unionController'
                    }
                }
            })
            //当日要闻列表
            .state('union.dayNewsList', {
                url: '/dayNewsList',
                cache: true,
                views: {
                    'union': {
                        templateUrl: 'templates/union/dayNewsList.html',
                        controller: 'unionController'
                    }
                }
            })

        //设置结束
        // if none of the above states are matched, use this as the fallback
        $urlRouterProvider.otherwise('/mine/mine');

    }).directive('hideTabs', function ($rootScope, $location) {
    return {
        restrict: 'AE',
        link: function ($scope) {
            //不想隐藏的时候就不能隐藏了，可以监听$ionicView.beforeEnter
            $rootScope.hideTabs = 'tabs-item-hide';

            $scope.$on('$ionicView.beforeEnter', function () {
                if ($location.path() == '/index/index' || $location.path() == '/cart/cart' || $location.path() == '/mine/mine' || $location.path() == '/set/set') {
                    $rootScope.hideTabs = ' ';
                }
            });

            $scope.$on('$ionicView.beforeLeave', function () {
                if ($location.path() == '/index/index' || $location.path() == '/cart/cart' || $location.path() == '/mine/mine' || $location.path() == '/set/set') {
                    $rootScope.hideTabs = ' ';
                }
            });
        }
    }
}).directive('dir', function ($compile, $parse) {//--ty--20160726
    return {
        restrict: 'EA',
        link: function (scope, element, attr) {
            scope.$watch(attr.content, function () {
                element.html($parse(attr.content)(scope));
                $compile(element.contents())(scope);
            }, true);
        }
    }
}).filter('cut', function () {
    return function (value, wordwise, max, tail) {
        if (!value) return '';

        max = parseInt(max, 10);
        if (!max) return value;
        if (value.length <= max) return value;

        value = value.substr(0, max);
        if (wordwise) {
            var lastspace = value.lastIndexOf(' ');
            if (lastspace != -1) {
                value = value.substr(0, lastspace);
            }
        }

        return value + (tail || '...');
    };
});